# -*- coding: utf-8 -*-

__all__ = [
    'milvus_pb2', 'milvus_pb2_grpc',
    'common_pb2',
    'schema_pb2',
]
